#
# spec file for package nvptx-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nvptx-tools
Version:        1.0+git.20230913.c321f1a
Release:        1.1
Summary:        PTX language tools
License:        GPL-3.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/MentorEmbedded/nvptx-tools/
Source:         %{name}-%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Note that w/o a CUDA development (at least cuda.h and libcuda.so) the
# tools for executing are not built.  CUDA is not free software.
BuildRequires:  gcc-c++
# The package is used for NVPTX offloading support in GCC which is currently
# only enabled on x86_64 and aarch64
ExclusiveArch:  x86_64 aarch64

%description
A collection of tools for use with nvptx-none (NVIDIA Parallel Thread
Execution) GCC toolchains.

* nvptx-none-as: "assembler" for PTX.
* nvptx-none-ld: "linker" for PTX.
* nvptx-none-run: run PTX binaries compiled with -mmainkernel.
* nvptx-none-run-single: like nvptx-none-run, but locked, such that
  system-wide, only one instance of it is running at a time.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

%files
%defattr(-,root,root)
%dir %{_prefix}/nvptx-none
%{_prefix}/nvptx-none
%{_bindir}/nvptx-none-ar
%{_bindir}/nvptx-none-as
%{_bindir}/nvptx-none-ld
%{_bindir}/nvptx-none-nm
%{_bindir}/nvptx-none-ranlib
%{_bindir}/nvptx-none-run
%{_bindir}/nvptx-none-run-single
%doc COPYING3

%changelog
* Tue Sep 26 2023 rguenther@suse.com
- Update to version 1.0+git.20230913.c321f1a:
  * as: Allow for arbitrary number of tokens in a 'stmt'
  * Ensure :VAR_MAP and :FUNC_MAP are output in order, part II [#29]
  * Ensure :VAR_MAP and :FUNC_MAP are output in order: add more test cases [#29]
  * as: Pass 'Vis' into 'parse_line_nosemi'
  * as: Inline 'alloc_comment'
  * as: When tokenizing a block comment, don't lose a preceding end of line marker
  * as: Add 'test/as/block_comment-1.test'
  * Bump architecture baseline from sm_35 to sm_50 [#30]
  * as: Remove unused 'FUNC_MAP', 'VAR_MAP' scanning
  * as: Clean up 'symbol's via C++ destructor
  * Enable 'test/as/ptxas/missing-1.test' also if 'ptxas' is available
  * Adjust for 'pex_run' error message change in "Update imported files: GCC, 2018-10-29 [#1, #42]"
  * Update imported files: GCC, 2023-06-16 [#1, #42]
  * Update imported files: GCC, 2022-05-18, II [#1, #42]
  * Update imported files: GCC, 2022-05-18 [#1, #42]
  * Update imported files: GCC, 2022-04-06 [#1, #42]
  * Update imported files: GCC, 2022-03-20 [#1, #42]
  * Switch to Autoconf 2.69, Automake 1.15.1 [#42]
  * Update imported files: GCC, 2018-10-31 [#1, #42]
  * Update imported files: GCC, 2018-10-29 [#1, #42]
  * Update imported files: GCC, 2016-07-29 [#1, #42]
  * Update imported files: GCC, 2014-05-01 [#1, #42]
  * Note "Imported Files" in 'README-development' [#1]
  * Add 'move-if-change' [#1]
  * Remove 'acinclude.m4'
  * Don't use 'gcc_AC_PROG_INSTALL'; use standard 'AC_PROG_INSTALL'
  * Don't use 'gcc_AC_PROG_LN_S'; assume that 'ln -s' does work
  * Have 'aclocal.m4' be "generated automatically by aclocal"
  * Move 'ACX_PKGVERSION', 'ACX_BUGURL' into 'config/acx.m4'
  * Regenerate 'configure'
  * Ensure :VAR_MAP and :FUNC_MAP are output in order
* Fri Jul 21 2023 rguenther@suse.com
- Update to version 1.0+git.20230718.bbb6fe6:
  * Document "Program Instrumentation: Sanitizers" in 'README-development'
  * run: Move 'cuModuleGetFunction' for '__main' out of 'compile_file'
  * run: Plug 'compile_file' memory leaks
  * run: Localize 'cuda_lib'
  * as: Localize 'collect_wait'
  * as: Don't 'unlink (NULL)'
  * as: Don't use an obstack for 'ptxas' invocation [#1]
  * ld: Remove unused '#include "obstack.h"' [#1]
  * ld, nm: Stop 'using namespace std;'
  * run: For auto '--stack-size', consider free instead of total device memory [#8]
  * ld: Support archives appearing as input files
  * ld: Don't reject empty archives
  * ld: Make resolving of '-l'ibraries a separate step
  * ld: Verify no NUL-separated parts for 'process_refs_defs'
  * ld: Fix undefined behavior reading objects from archives
  * ld: Document padding of objects in archives
  * as: Plug 'alloc_stmt' memory leak
  * as: Plug 'read_file' memory leak
  * as: Plug 'tokenize' memory leak
  * as: Conceptually simplify capture of preamble '.target' directive's argument
  * 'test/GLOBAL_FUNCTION_DECL_f.s': 'f' is '.extern', not '.visible' [#38]
* Tue Mar 21 2023 mliska@suse.cz
- Start using tar_scm OBS server for a tarball.
- Update to version 1.0+git.20230122.93e0090:
  * nm: '#define __STDC_FORMAT_MACROS' for '#include <inttypes.h>' [#40]
  * 'nm'
  * ld: Clean up the 'symbol_table' when we're done
  * as: Clean up the 'symbol_table' when we're done
  * ld: Clean up 'file_hash_entry' instances when we're done with the 'symbol_table'
  * as: Always 'free' the 'tok_preamble_target_arg'-deduced 'target_arg' string after 'ptxas' verification
  * as: 'obstack_free' after 'ptxas' verification
  * run: Close files after use
* Thu Oct 13 2022 Richard Biener <rguenther@suse.com>
- Update nvptx-tools tarball from git
  * includes changes in nvptx-tools.patch
  * deals with CUDA 11 dropping support for NVIDIA Kepler sm_30 and sm_32
- Remove nvptx-tools.patch as it is included in the above tarball update
- Package nvptx-none-run and nvptx-none-run-single tools
* Wed Jun  3 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build on aarch64
* Tue Sep  5 2017 rguenther@suse.com
- Update nvptx-tools.patch to check for getopt to avoid providing
  an incompatible declaration.
* Mon Feb  6 2017 jengelh@inai.de
- Update description
* Mon Feb  6 2017 rguenther@suse.com
- Package COPYING3.
* Thu Jan 26 2017 rguenther@suse.com
- Initial version.
- Add nvptx-tools.patch to avoid errors when ptxas is not available.
